Module actor

Module actor 

Structs

CurlActor
Request
This contains the Easy2 object and a oneshot sender channel when passing into the background task to perform Curl asynchronously.

Enums

TransferType
This enum is used to differentiate between the two types of transfers: Multi and Easy2.

Traits

Actor