Structs
- Curl
Actor - Request
- This contains the Easy2 object and a oneshot sender channel when passing into the background task to perform Curl asynchronously.
Enums
- Transfer
Type - This enum is used to differentiate between the two types of transfers: Multi and Easy2.