CurlActor

Struct CurlActor 

pub struct CurlActor<H>
where H: Handler + Debug + Send + 'static,
{ /* private fields */ }

Implementations

Source

impl<H> CurlActor<H>
where H: Handler + Debug + Send + 'static,

pub fn new() -> Self

This creates the new instance of CurlActor to handle Curl perform asynchronously using Curl Multi in a background thread to avoid blocking of other tasks.

pub fn new_runtime(runtime: Runtime) -> Self

This creates the new instance of CurlActor to handle Curl perform asynchronously using Curl Multi in a background thread to avoid blocking of other tasks. The user can provide a custom runtime to use for the background task.

pub fn new_runtime_with_capacity(runtime: Runtime, capacity: usize) -> Self

Create a new CurlActor with a user-provided runtime and configurable channel capacity.