pub struct CurlActor<H>{ /* private fields */ }Implementations
Sourceimpl<H> CurlActor<H>
impl<H> CurlActor<H>
Sourcepub fn new() -> Self
pub fn new() -> Self
This creates the new instance of CurlActor to handle Curl perform asynchronously using Curl Multi in a background thread to avoid blocking of other tasks.
Sourcepub fn new_runtime(runtime: Runtime) -> Self
pub fn new_runtime(runtime: Runtime) -> Self
This creates the new instance of CurlActor to handle Curl perform asynchronously using Curl Multi in a background thread to avoid blocking of other tasks. The user can provide a custom runtime to use for the background task.
Sourcepub fn new_runtime_with_capacity(runtime: Runtime, capacity: usize) -> Self
pub fn new_runtime_with_capacity(runtime: Runtime, capacity: usize) -> Self
Create a new CurlActor with a user-provided runtime and configurable channel capacity.